@@ -1,7 +1,7 @@
-import pytest
-import numpy as np
 import discretisedfield as df
 import micromagneticmodel as mm
+import numpy as np
+import pytest
 
 
 class TestDamping:
@@ -14,13 +14,13 @@ class TestDamping:
         p2 = (5e-9, 5e-9, 3e-9)
         self.region = df.Region(p1=p1, p2=p2)
         self.n = (10, 10, 10)
-        self.subregions = {'r1': df.Region(p1=(-5e-9, -5e-9, -3e-9),
-                                           p2=(5e-9, 0, 3e-9)),
-                           'r2': df.Region(p1=(-5e-9, 0, -3e-9),
-                                           p2=(5e-9, 5e-9, 3e-9))}
+        self.subregions = {
+            "r1": df.Region(p1=(-5e-9, -5e-9, -3e-9), p2=(5e-9, 0, 3e-9)),
+            "r2": df.Region(p1=(-5e-9, 0, -3e-9), p2=(5e-9, 5e-9, 3e-9)),
+        }
 
     def test_scalar(self):
-        name = 'damping_scalar'
+        name = "damping_scalar"
 
         H = (0, 0, 1e6)
         alpha = 0
@@ -38,19 +38,18 @@ class TestDamping:
 
         # Alpha is zero, nothing should change.
         value = system.m(mesh.region.random_point())
-        assert np.linalg.norm(np.cross(value, (0, 0.1*Ms, Ms))) < 1e-3
+        assert np.linalg.norm(np.cross(value, (0, 0.1 * Ms, Ms))) < 1e-3
 
         self.calculator.delete(system)
 
     def test_dict(self):
-        name = 'damping_dict'
+        name = "damping_dict"
 
         H = (0, 0, 1e6)
-        alpha = {'r1': 0, 'r2': 1}
+        alpha = {"r1": 0, "r2": 1}
         Ms = 1e6
 
-        mesh = df.Mesh(region=self.region, n=self.n,
-                       subregions=self.subregions)
+        mesh = df.Mesh(region=self.region, n=self.n, subregions=self.subregions)
 
         system = mm.System(name=name)
         system.energy = mm.Zeeman(H=H)
@@ -62,7 +61,7 @@ class TestDamping:
 
         # alpha=0 region
         value = system.m((1e-9, -4e-9, 3e-9))
-        assert np.linalg.norm(np.cross(value, (0, 0.1*Ms, Ms))) < 1e-3
+        assert np.linalg.norm(np.cross(value, (0, 0.1 * Ms, Ms))) < 1e-3
 
         # alpha!=0 region
         value = system.m((1e-9, 4e-9, 3e-9))
@@ -71,7 +70,7 @@ class TestDamping:
         self.calculator.delete(system)
 
     def test_field(self):
-        name = 'damping_field'
+        name = "damping_field"
 
         mesh = df.Mesh(region=self.region, n=self.n)
 
@@ -96,7 +95,7 @@ class TestDamping:
 
         # alpha=0 region
         value = system.m((1e-9, -4e-9, 3e-9))
-        assert np.linalg.norm(np.cross(value, (0, 0.1*Ms, Ms))) < 1e-3
+        assert np.linalg.norm(np.cross(value, (0, 0.1 * Ms, Ms))) < 1e-3
 
         # alpha!=0 region
         value = system.m((1e-9, 4e-9, 3e-9))
